@@ -71,9 +71,9 @@ extract_df <- function(x, path) {
   if (!all(is.na(nm))) {
     nodes <- xset(x, paste0(path, "*"))
     list <- split(vapply(nodes, XML::xmlValue, ""), nm)
-    data.frame(stringsAsFactors = FALSE, list)[, nm]
+    tibble::as_tibble(list, validate = TRUE)[, nm]
   } else {
-    data.frame()
+    tibble::tibble()
   }
 }
 
@@ -84,7 +84,7 @@ extract_df <- function(x, path) {
 #' 
 #' @details
 #' See the official online documentation for NCBI's
-#' \href{http://www.ncbi.nlm.nih.gov/books/NBK25499//#chapter4.EInfo}{EUtilities}
+#' \href{https://www.ncbi.nlm.nih.gov/books/NBK25499/#chapter4.EInfo}{EUtilities}
 #' for additional information.
 #' 
 #' @title einfo - getting database statistics and search fields
@@ -130,7 +130,7 @@ einfo <- function(db = NULL, version = "2.0", retmode = "xml") {
   .einfo(method = "GET", db = db, version = version, retmode = retmode)
 }
 
-#' @describeIn content
+#' @describeIn content Access the data content from an \code{einfo} request.
 setMethod("content", "einfo", function(x, as = NULL) {
   callNextMethod(x = x, as = as)
 })
