@@ -41,7 +41,7 @@ NULL
 #' 
 #' @details
 #' See the official online documentation for NCBI's
-#' \href{http://www.ncbi.nlm.nih.gov/books/NBK25499//#chapter4.ESummary}{EUtilities}
+#' \href{https://www.ncbi.nlm.nih.gov/books/NBK25499/#chapter4.ESummary}{EUtilities}
 #' for additional information.
 #'
 #' @title esummary - downloading Document Summaries
@@ -78,8 +78,8 @@ NULL
 #' @export
 #' @examples
 #' ## Retrieve the Document Summary information for a set of
-#' ## UIDs frome the Gene datanase.
-#' ds <- esummary(c("828392", "790", "470338"), "gene")
+#' ## UIDs frome the Nuccore datanase.
+#' ds <- esummary(c("1060721643", "1060721620", "1060721618"), "nuccore")
 #' ds
 #' 
 #' \dontrun{
@@ -88,7 +88,7 @@ NULL
 #' df
 #' 
 #' ## use XPath expressions to extract nodes of interest
-#' ds['//TaxID']
+#' ds['//TaxId/text()']
 #' }
 esummary <- function(uid, db = NULL, retstart = 1, retmax = 10000,
                       querykey = NULL, webenv = NULL, retmode = 'xml',
@@ -96,6 +96,9 @@ esummary <- function(uid, db = NULL, retstart = 1, retmax = 10000,
   ## extract query parameters
   params <- parse_params(uid, db, querykey, webenv)
   retmode <- match.arg(retmode, c('xml', 'json'))
+  if (!is.null(params$querykey) && !is.null(params$webenv)) {
+    retstart <- retstart - 1L
+  }
   if (retmax > 10000) {
     stop("Number of DocSums to be downloaded should not exceed 10,000.", call.=FALSE)
   }
@@ -106,7 +109,7 @@ esummary <- function(uid, db = NULL, retstart = 1, retmax = 10000,
             version = if (version == "2.0") "2.0" else NULL)
 }
 
-#' @describeIn content
+#' @describeIn content Access the data content from an \code{esummary} request.
 setMethod("content", "esummary", function(x, as = NULL) {
   callNextMethod(x = x, as = as)
 })
@@ -125,8 +128,7 @@ setMethod("content", "esummary", function(x, as = NULL) {
 #' ds <- esummary("470338", "protein")
 #' ds["//Slen/node()"]
 #' 
-#' library("XML")
-#' as.numeric(xmlValue(ds[["//Slen"]]))
+#' as.numeric(XML::xmlValue(ds[["//Slen"]]))
 #' }
 setMethod("[", c("esummary", "character"), function(x, i) {
   x$xmlSet(i)  
