@@ -1,5 +1,4 @@
 library(testthat)
-library(reutils)
 opts <- options(reutils.verbose.queries = FALSE, reutils.email = "test@mail.com")
-test_package("reutils")
+test_check("reutils")
 options(opts)
\ No newline at end of file
